@@ -1,6 +1,6 @@
-from utils.common import *
-from core.base import Tensor, Parameter
-import nn.td_functional
+from xs.utils.common import *
+from xs.core.base import Tensor, Parameter
+import xs.nn.td_functional
 
 
 def AddBackward(outputs: Tensor):
@@ -8,10 +8,10 @@ def AddBackward(outputs: Tensor):
         if in_bound.requires_grad:
             not_equal_axis = [k for k, v in enumerate(outputs.shape) if v != in_bound.shape[k]]
             if not_equal_axis:
-                nn.td_functional.add(in_bound.grad.eval, GLOBAL.np.sum(outputs.grad.eval, axis=not_equal_axis[0]), in_bound.grad.eval)
+                xs.nn.td_functional.add(in_bound.grad.eval, GLOBAL.np.sum(outputs.grad.eval, axis=not_equal_axis[0]), in_bound.grad.eval)
                 # in_bound.grad.eval += GLOBAL.np.sum(outputs.grad.eval, axis=not_equal_axis[0])
             else:
-                nn.td_functional.add(in_bound.grad.eval, outputs.grad.eval,
+                xs.nn.td_functional.add(in_bound.grad.eval, outputs.grad.eval,
                                      in_bound.grad.eval)
                 # in_bound.grad.eval += outputs.grad.eval
 
@@ -30,7 +30,7 @@ def SubBackward(outputs: Tensor):
                 grad = -grad
 
             # in_bound.grad.eval += grad
-            nn.td_functional.add(in_bound.grad.eval, grad, in_bound.grad.eval)
+            xs.nn.td_functional.add(in_bound.grad.eval, grad, in_bound.grad.eval)
 
 
 def MultiplyBackward(outputs: Tensor):
@@ -51,10 +51,10 @@ def MultiplyBackward(outputs: Tensor):
             not_equal_axis = [k for k, v in enumerate(outputs.shape) if v != in_bound.shape[k]]
             if not_equal_axis:
                 # in_bound.grad.eval += GLOBAL.np.sum(outputs.grad.eval * product_except_self_list[i], axis=not_equal_axis[0])
-                nn.td_functional.add(in_bound.grad.eval, GLOBAL.np.sum(outputs.grad.eval * product_except_self_list[i], axis=not_equal_axis[0]), in_bound.grad.eval)
+                xs.nn.td_functional.add(in_bound.grad.eval, GLOBAL.np.sum(outputs.grad.eval * product_except_self_list[i], axis=not_equal_axis[0]), in_bound.grad.eval)
             else:
                 # in_bound.grad.eval += outputs.grad.eval * product_except_self_list[i]
-                nn.td_functional.add(in_bound.grad.eval, outputs.grad.eval * product_except_self_list[i], in_bound.grad.eval)
+                xs.nn.td_functional.add(in_bound.grad.eval, outputs.grad.eval * product_except_self_list[i], in_bound.grad.eval)
 
 
 def PowBackward(outputs: Tensor):
@@ -62,12 +62,12 @@ def PowBackward(outputs: Tensor):
     if inputs.requires_grad:
         exp = outputs.cache['exp']
         if exp == 1:
-            nn.td_functional.add(inputs.grad.eval, outputs.grad.eval, inputs.grad.eval)
+            xs.nn.td_functional.add(inputs.grad.eval, outputs.grad.eval, inputs.grad.eval)
         else:
             gradients = GLOBAL.np.power(inputs.eval, exp - 1)
             GLOBAL.np.multiply(gradients, exp, out=gradients)
             GLOBAL.np.multiply(outputs.grad.eval, gradients, out=gradients)
-            nn.td_functional.add(inputs.grad.eval, gradients, inputs.grad.eval)
+            xs.nn.td_functional.add(inputs.grad.eval, gradients, inputs.grad.eval)
                 
 
 def MMBackward(outputs):
@@ -75,11 +75,11 @@ def MMBackward(outputs):
     x, y = outputs.in_bounds
     if x.requires_grad:
         # GLOBAL.np.add(x.grad.eval, GLOBAL.np.dot(outputs.grad.eval, y.eval.T), out=x.grad.eval)
-        nn.td_functional.add(x.grad.eval, GLOBAL.np.dot(outputs.grad.eval, y.eval.T), x.grad.eval)
+        xs.nn.td_functional.add(x.grad.eval, GLOBAL.np.dot(outputs.grad.eval, y.eval.T), x.grad.eval)
         # x.grad.eval += GLOBAL.np.dot(outputs.grad.eval, y.eval.T)
     if y.requires_grad:
         # GLOBAL.np.add(y.grad.eval, GLOBAL.np.dot(x.eval.T, outputs.grad.eval), out=y.grad.eval)
-        nn.td_functional.add(y.grad.eval, GLOBAL.np.dot(x.eval.T, outputs.grad.eval), y.grad.eval)
+        xs.nn.td_functional.add(y.grad.eval, GLOBAL.np.dot(x.eval.T, outputs.grad.eval), y.grad.eval)
         # y.grad.eval += GLOBAL.np.dot(x.eval.T, outputs.grad.eval)
 
 
@@ -122,7 +122,7 @@ def MaximumBackward(outputs):
 def SumBackward(outputs):
     inputs, = outputs.in_bounds
     if inputs.requires_grad:
-        inputs.grad.eval += GLOBAL.np.multiply(GLOBAL.np.ones_like(inputs.eval), nn.td_functional.expand_as(outputs.grad.eval, inputs.eval))
+        inputs.grad.eval += GLOBAL.np.multiply(GLOBAL.np.ones_like(inputs.eval), xs.nn.td_functional.expand_as(outputs.grad.eval, inputs.eval))
 
 
 def MeanBackward(outputs):
@@ -394,14 +394,14 @@ def BatchNormBackward(outputs: Tensor):
         # dx = N * dx_ - GLOBAL.np.sum(dx_, axis=0) - x_ * GLOBAL.np.sum(dx_ * x_, axis=0)
         # dx *= (1.0 / N) / GLOBAL.np.sqrt(var_plus_eps)
 
-        # grad = GLOBAL.np.multiply(grad, nn.td_functional.expand_as(gamma.eval, grad))
+        # grad = GLOBAL.np.multiply(grad, xs.nn.td_functional.expand_as(gamma.eval, grad))
         # GLOBAL.np.multiply(N, sqrtvar, out=sqrtvar)
         # GLOBAL.np.divide(1., sqrtvar, out=sqrtvar)
         # dx = 1 / (N * GLOBAL.np.sqrt(var_eps)) * (dx_hat * N - GLOBAL.np.sum(dx_hat, axis=0) - x_hat * GLOBAL.np.sum(dx_hat * x_hat, axis=0))
         # GLOBAL.np.multiply(normalized_x, GLOBAL.np.sum(GLOBAL.np.multiply(grad, normalized_x), axis=axis_field, keepdims=True), out=normalized_x)
         # GLOBAL.np.subtract(GLOBAL.np.subtract(GLOBAL.np.multiply(grad, N), GLOBAL.np.sum(grad, axis=axis_field, keepdims=True)), normalized_x, out=grad)
         # GLOBAL.np.multiply(sqrtvar, grad, out=grad)
-        dx_ = GLOBAL.np.multiply(grad, nn.td_functional.expand_as(gamma.eval, grad))
+        dx_ = GLOBAL.np.multiply(grad, xs.nn.td_functional.expand_as(gamma.eval, grad))
         GLOBAL.np.multiply(N, sqrtvar, out=sqrtvar)
         GLOBAL.np.divide(1., sqrtvar, out=sqrtvar)
 
@@ -559,7 +559,7 @@ def BCELossBackward(outputs: Tensor):
 
 def BCEWithLogitsLossBackward(outputs: Tensor):
     y_pred, y_true = outputs.in_bounds
-    logits = nn.td_functional.sigmoid(y_pred.eval)
+    logits = xs.nn.td_functional.sigmoid(y_pred.eval)
     gradients = GLOBAL.np.subtract(GLOBAL.np.divide(GLOBAL.np.subtract(1, y_true.eval), GLOBAL.np.subtract(1, logits)), GLOBAL.np.divide(y_true.eval, logits))
     if outputs.cache['reduction'] == 'mean':
         avg = GLOBAL.np.prod(y_pred.shape)
