@@ -1,4 +1,4 @@
-from optim.optimizer import *
+from xs.optim.optimizer import *
 
 
 class AdaGrad(Optimizer):
@@ -9,10 +9,10 @@ class AdaGrad(Optimizer):
 
     def step(self):
         if self.ms is None:
-            self.ms = [np.zeros_like(g.eval) for g in self._parameters]
+            self.ms = [GLOBAL.np.zeros_like(g.eval) for g in self._parameters]
         for i, (s, var)in enumerate(zip(self.ms, self._parameters)):
             if var.requires_grad:
-                s += np.power(var.grad.eval, 2)
-                var.eval -= self.lr * var.grad.eval / np.sqrt(s + self.epsilon)
+                s += GLOBAL.np.power(var.grad.eval, 2)
+                var.eval -= self.lr * var.grad.eval / GLOBAL.np.sqrt(s + self.epsilon)
                 self.ms[i] = s
         super(AdaGrad, self).step()
