@@ -1,4 +1,4 @@
-from optim.optimizer import *
+from xs.optim.optimizer import *
 
 
 class Adam(Optimizer):
@@ -14,17 +14,17 @@ class Adam(Optimizer):
         self.iterations += 1
         if self.ms is None:
             # initialize
-            self.ms = [np.zeros_like(p.eval) for p in self._parameters]
+            self.ms = [GLOBAL.np.zeros_like(p.eval) for p in self._parameters]
         if self.vs is None:
             # initialize
-            self.vs = [np.zeros_like(p.eval) for p in self._parameters]
+            self.vs = [GLOBAL.np.zeros_like(p.eval) for p in self._parameters]
 
         for i, (v, m, var) in enumerate(zip(self.vs, self.ms, self._parameters)):
             if var.requires_grad:
                 v = self.beta1 * v + (1 - self.beta1) * var.grad.eval
-                m = self.beta2 * m + (1 - self.beta2) * np.square(var.grad.eval)
+                m = self.beta2 * m + (1 - self.beta2) * GLOBAL.np.square(var.grad.eval)
                 v_correct = v / (1 - pow(self.beta1, self.iterations))
                 m_correct = m / (1 - pow(self.beta2, self.iterations))
-                var.eval -= self.lr * (v_correct / (np.sqrt(m_correct) + self.epsilon))
+                var.eval -= self.lr * (v_correct / (GLOBAL.np.sqrt(m_correct) + self.epsilon))
                 self.ms[i] = m
                 self.vs[i] = v
